<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('checkin');

// 记录访问日志
record_log('访问入住登记页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加入住记录
    if ($_POST['action'] == 'add') {
        $checkin_no = isset($_POST['checkin_no']) ? trim($_POST['checkin_no']) : '';
        $guest_name = isset($_POST['guest_name']) ? trim($_POST['guest_name']) : '';
        $guest_mobile = isset($_POST['guest_mobile']) ? trim($_POST['guest_mobile']) : '';
        $id_number = isset($_POST['id_number']) ? trim($_POST['id_number']) : '';
        $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;
        $room_id = isset($_POST['room_id']) ? intval($_POST['room_id']) : 0;
        $checkin_time = isset($_POST['checkin_time']) ? trim($_POST['checkin_time']) : date('Y-m-d H:i:s');
        $checkout_time = isset($_POST['checkout_time']) ? trim($_POST['checkout_time']) : null;
        $deposit_amount = isset($_POST['deposit_amount']) ? floatval($_POST['deposit_amount']) : 0;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if (empty($checkin_no) || empty($guest_name) || empty($guest_mobile) || $room_id <= 0) {
            $error = '请填写完整入住信息！';
        } else {
            try {
                // 检查入住单号是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM checkin_orders WHERE checkin_no = ?");
                $stmt->execute([$checkin_no]);
                if ($stmt->fetchColumn() > 0) {
                    $error = '入住单号已存在！';
                } else {
                    // 检查房间是否可用
                    $stmt = $pdo->prepare("
                        SELECT r.*, t.type_name, t.price 
                        FROM room_info r 
                        JOIN room_types t ON r.room_type_id = t.id 
                        WHERE r.id = ? AND r.status = 1
                    ");
                    $stmt->execute([$room_id]);
                    $room = $stmt->fetch();

                    if (!$room) {
                        $error = '所选房间不可用！';
                    } else {
                        // 开始事务
                        $pdo->beginTransaction();

                        // 添加入住订单
                        $stmt = $pdo->prepare("
                            INSERT INTO checkin_orders (
                                checkin_no, guest_name, guest_mobile, id_number,
                                member_id, room_id, checkin_time, checkout_time,
                                room_rate, deposit_amount, status,
                                create_by, remark
                            ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, 1, ?, ?)
                        ");
                        $result = $stmt->execute([
                            $checkin_no,
                            $guest_name,
                            $guest_mobile,
                            $id_number,
                            $member_id > 0 ? $member_id : null,
                            $room_id,
                            $checkin_time,
                            $checkout_time,
                            $room['price'],
                            $deposit_amount,
                            $_SESSION['user_id'],
                            $remark
                        ]);

                        if ($result) {
                            $checkin_id = $pdo->lastInsertId();

                            // 更新房间状态为已入住
                            $stmt = $pdo->prepare("UPDATE room_info SET status = 2 WHERE id = ?");
                            $room_updated = $stmt->execute([$room_id]);

                            // 记录押金交易
                            if ($deposit_amount > 0) {
                                $stmt = $pdo->prepare("
                                    INSERT INTO checkin_transactions (
                                        checkin_id, type, amount, 
                                        payment_method, operator_id, remark
                                    ) VALUES (?, 4, ?, 1, ?, '入住押金')
                                ");
                                $deposit_recorded = $stmt->execute([
                                    $checkin_id,
                                    $deposit_amount,
                                    $_SESSION['user_id']
                                ]);
                            } else {
                                $deposit_recorded = true;
                            }

                            // 如果是会员，更新会员入住次数
                            if ($member_id > 0) {
                                $stmt = $pdo->prepare("
                                    UPDATE guest_members 
                                    SET stay_count = stay_count + 1 
                                    WHERE id = ?
                                ");
                                $member_updated = $stmt->execute([$member_id]);
                            } else {
                                $member_updated = true;
                            }

                            if ($room_updated && $deposit_recorded && $member_updated) {
                                $pdo->commit();
                                record_log("登记入住：{$guest_name}，房间号：{$room['room_number']}");
                                $success = '入住登记成功！';
                            } else {
                                $pdo->rollBack();
                                $error = '入住登记失败：数据更新出错！';
                            }
                        } else {
                            $pdo->rollBack();
                            $error = '入住登记失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑入住记录
    elseif ($_POST['action'] == 'edit') {
        $checkin_id = isset($_POST['checkin_id']) ? intval($_POST['checkin_id']) : 0;
        $guest_name = isset($_POST['guest_name']) ? trim($_POST['guest_name']) : '';
        $guest_mobile = isset($_POST['guest_mobile']) ? trim($_POST['guest_mobile']) : '';
        $id_number = isset($_POST['id_number']) ? trim($_POST['id_number']) : '';
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($checkin_id <= 0 || empty($guest_name) || empty($guest_mobile)) {
            $error = '请填写完整入住信息！';
        } else {
            try {
                // 检查入住记录是否存在且未退房
                $stmt = $pdo->prepare("
                    SELECT co.*, r.room_number 
                    FROM checkin_orders co
                    JOIN room_info r ON co.room_id = r.id
                    WHERE co.id = ? AND co.status = 1
                ");
                $stmt->execute([$checkin_id]);
                $checkin = $stmt->fetch();

                if (!$checkin) {
                    $error = '入住记录不存在或已退房！';
                } else {
                    $stmt = $pdo->prepare("
                        UPDATE checkin_orders 
                        SET guest_name = ?, guest_mobile = ?, id_number = ?,
                            remark = ?
                        WHERE id = ?
                    ");
                    $result = $stmt->execute([
                        $guest_name,
                        $guest_mobile,
                        $id_number,
                        $remark,
                        $checkin_id
                    ]);

                    if ($result) {
                        record_log("编辑入住记录：{$guest_name}，房间号：{$checkin['room_number']}");
                        $success = '入住信息更新成功！';
                    } else {
                        $error = '入住信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 取消入住
    elseif ($_POST['action'] == 'cancel') {
        $checkin_id = isset($_POST['checkin_id']) ? intval($_POST['checkin_id']) : 0;

        if ($checkin_id <= 0) {
            $error = '无效的入住记录ID！';
        } else {
            try {
                // 检查入住记录是否存在且未退房
                $stmt = $pdo->prepare("
                    SELECT co.*, r.room_number 
                    FROM checkin_orders co
                    JOIN room_info r ON co.room_id = r.id
                    WHERE co.id = ? AND co.status = 1
                ");
                $stmt->execute([$checkin_id]);
                $checkin = $stmt->fetch();

                if (!$checkin) {
                    $error = '入住记录不存在或已退房！';
                } else {
                    // 开始事务
                    $pdo->beginTransaction();

                    // 更新入住状态为已取消
                    $stmt = $pdo->prepare("
                        UPDATE checkin_orders 
                        SET status = 3
                        WHERE id = ?
                    ");
                    $checkin_updated = $stmt->execute([$checkin_id]);

                    // 更新房间状态为可用
                    $stmt = $pdo->prepare("UPDATE room_info SET status = 1 WHERE id = ?");
                    $room_updated = $stmt->execute([$checkin['room_id']]);

                    // 如果有押金，创建退还押金记录
                    if ($checkin['deposit_amount'] > 0) {
                        $stmt = $pdo->prepare("
                            INSERT INTO checkin_transactions (
                                checkin_id, type, amount, 
                                payment_method, operator_id, remark
                            ) VALUES (?, 5, ?, 1, ?, '取消入住退还押金')
                        ");
                        $deposit_returned = $stmt->execute([
                            $checkin_id,
                            $checkin['deposit_amount'],
                            $_SESSION['user_id']
                        ]);
                    } else {
                        $deposit_returned = true;
                    }

                    if ($checkin_updated && $room_updated && $deposit_returned) {
                        $pdo->commit();
                        record_log("取消入住：{$checkin['guest_name']}，房间号：{$checkin['room_number']}");
                        $success = '入住记录取消成功！';
                    } else {
                        $pdo->rollBack();
                        $error = '入住记录取消失败！';
                    }
                }
            } catch (PDOException $e) {
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 如果是编辑请求，获取入住详情
$edit_checkin = null;
if (isset($_GET['edit']) && intval($_GET['edit']) > 0) {
    $checkin_id = intval($_GET['edit']);
    try {
        $stmt = $pdo->prepare("
            SELECT co.*, r.room_number, r.room_type_id, t.type_name
            FROM checkin_orders co
            JOIN room_info r ON co.room_id = r.id
            JOIN room_types t ON r.room_type_id = t.id
            WHERE co.id = ? AND co.status = 1
        ");
        $stmt->execute([$checkin_id]);
        $edit_checkin = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取入住详情失败：' . $e->getMessage();
    }
}

// 判断是否查看详情
$view_checkin_id = isset($_GET['view']) ? intval($_GET['view']) : 0;

// 获取所有可用房间
try {
    $stmt = $pdo->query("
        SELECT r.*, t.type_name, t.price
        FROM room_info r
        JOIN room_types t ON r.room_type_id = t.id
        WHERE r.status = 1
        ORDER BY r.room_number
    ");
    $available_rooms = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取可用房间列表失败：' . $e->getMessage();
    $available_rooms = [];
}

// 获取所有会员
try {
    $stmt = $pdo->query("
        SELECT id, member_no, name, mobile
        FROM guest_members
        WHERE status = 1
        ORDER BY id DESC
    ");
    $members = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取会员列表失败：' . $e->getMessage();
    $members = [];
}

// 获取所有入住记录
try {
    $stmt = $pdo->query("
        SELECT co.*, r.room_number, t.type_name, 
               m.member_no, u.username AS operator_name
        FROM checkin_orders co
        JOIN room_info r ON co.room_id = r.id
        JOIN room_types t ON r.room_type_id = t.id
        LEFT JOIN guest_members m ON co.member_id = m.id
        LEFT JOIN sys_users u ON co.create_by = u.id
        ORDER BY co.checkin_time DESC
    ");
    $checkin_orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取入住记录列表失败：' . $e->getMessage();
    $checkin_orders = [];
}

// 生成新的入住单号
$new_checkin_no = 'CI' . date('YmdHis');
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>入住登记</h2>
            <div class="breadcrumb">
                <a href="index.php">入住与退房管理</a> &gt; 入住登记
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_add_form && !$edit_checkin): ?>
                    <a href="checkin.php?show_form=add" class="btn btn-primary">新增入住</a>
                <?php endif; ?>
            </div>

            <?php if ($show_add_form): ?>
                <!-- 添加入住表单 -->
                <h3>新增入住</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="checkin_no">入住单号：</label>
                            <input type="text" id="checkin_no" name="checkin_no" value="<?php echo $new_checkin_no; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="room_id">房间：</label>
                            <select id="room_id" name="room_id" required>
                                <option value="">请选择房间</option>
                                <?php foreach ($available_rooms as $room): ?>
                                    <option value="<?php echo $room['id']; ?>">
                                        <?php echo $room['room_number']; ?> (<?php echo $room['type_name']; ?>) -
                                        ￥<?php echo $room['price']; ?>/天
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="guest_name">客人姓名：</label>
                            <input type="text" id="guest_name" name="guest_name" required>
                        </div>

                        <div class="form-group">
                            <label for="guest_mobile">手机号：</label>
                            <input type="text" id="guest_mobile" name="guest_mobile" required>
                        </div>

                        <div class="form-group">
                            <label for="id_number">证件号码：</label>
                            <input type="text" id="id_number" name="id_number">
                        </div>

                        <div class="form-group">
                            <label for="member_id">会员：</label>
                            <select id="member_id" name="member_id">
                                <option value="0">非会员</option>
                                <?php foreach ($members as $member): ?>
                                    <option value="<?php echo $member['id']; ?>">
                                        <?php echo $member['name']; ?> (<?php echo $member['member_no']; ?>) -
                                        <?php echo $member['mobile']; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="checkin_time">入住时间：</label>
                            <input type="datetime-local" id="checkin_time" name="checkin_time" value="<?php echo date('Y-m-d\TH:i'); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="checkout_time">预计退房时间：</label>
                            <input type="datetime-local" id="checkout_time" name="checkout_time" value="<?php echo date('Y-m-d\TH:i', strtotime('+1 day')); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="deposit_amount">押金：</label>
                            <input type="number" id="deposit_amount" name="deposit_amount" value="0" min="0" step="0.01">
                        </div>

                        <div class="form-group">
                            <label for="remark">备注：</label>
                            <textarea id="remark" name="remark" rows="3"></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="checkin.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($edit_checkin): ?>
                <!-- 编辑入住表单 -->
                <h3>编辑入住信息</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="edit">
                        <input type="hidden" name="checkin_id" value="<?php echo $edit_checkin['id']; ?>">

                        <div class="form-group">
                            <label>入住单号：</label>
                            <span class="form-static"><?php echo $edit_checkin['checkin_no']; ?></span>
                        </div>

                        <div class="form-group">
                            <label>房间：</label>
                            <span class="form-static">
                                <?php echo $edit_checkin['room_number']; ?> (<?php echo $edit_checkin['type_name']; ?>)
                            </span>
                        </div>

                        <div class="form-group">
                            <label for="guest_name">客人姓名：</label>
                            <input type="text" id="guest_name" name="guest_name" value="<?php echo $edit_checkin['guest_name']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="guest_mobile">手机号：</label>
                            <input type="text" id="guest_mobile" name="guest_mobile" value="<?php echo $edit_checkin['guest_mobile']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="id_number">证件号码：</label>
                            <input type="text" id="id_number" name="id_number" value="<?php echo $edit_checkin['id_number']; ?>">
                        </div>

                        <div class="form-group">
                            <label>入住时间：</label>
                            <span class="form-static"><?php echo date('Y-m-d H:i', strtotime($edit_checkin['checkin_time'])); ?></span>
                        </div>

                        <div class="form-group">
                            <label>押金：</label>
                            <span class="form-static">￥<?php echo number_format($edit_checkin['deposit_amount'], 2); ?></span>
                        </div>

                        <div class="form-group">
                            <label for="remark">备注：</label>
                            <textarea id="remark" name="remark" rows="3"><?php echo $edit_checkin['remark']; ?></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="checkin.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <?php if (!$show_add_form && !$edit_checkin): ?>
                <h3>入住记录列表</h3>
                <!-- 入住记录列表 -->
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>入住单号</th>
                                <th>客人姓名</th>
                                <th>房间号</th>
                                <th>房型</th>
                                <th>入住时间</th>
                                <th>退房时间</th>
                                <th>会员编号</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($checkin_orders as $order): ?>
                                <tr>
                                    <td><?php echo $order['id']; ?></td>
                                    <td><?php echo $order['checkin_no']; ?></td>
                                    <td><?php echo $order['guest_name']; ?></td>
                                    <td><?php echo $order['room_number']; ?></td>
                                    <td><?php echo $order['type_name']; ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($order['checkin_time'])); ?></td>
                                    <td><?php echo $order['checkout_time'] ? date('Y-m-d H:i', strtotime($order['checkout_time'])) : '-'; ?></td>
                                    <td><?php echo $order['member_no'] ?: '-'; ?></td>
                                    <td>
                                        <?php
                                        if ($order['status'] == 1) {
                                            echo '<span class="status-active">在住</span>';
                                        } elseif ($order['status'] == 2) {
                                            echo '<span class="status-inactive">已退房</span>';
                                        } elseif ($order['status'] == 3) {
                                            echo '<span class="status-warning">已取消</span>';
                                        }
                                        ?>
                                    </td>
                                    <td>
                                        <a href="checkin.php?view=<?php echo $order['id']; ?>" class="btn btn-sm btn-details">详情</a>

                                        <?php if ($order['status'] == 1): ?>
                                            <a href="checkin.php?edit=<?php echo $order['id']; ?>" class="btn btn-sm btn-edit">编辑</a>

                                            <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要取消此入住记录吗？此操作会释放房间并退还押金！');">
                                                <input type="hidden" name="action" value="cancel">
                                                <input type="hidden" name="checkin_id" value="<?php echo $order['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger">取消</button>
                                            </form>

                                            <a href="checkout.php?id=<?php echo $order['id']; ?>" class="btn btn-sm btn-warning">退房</a>
                                        <?php endif; ?>
                                    </td>
                                </tr>

                                <?php if ($view_checkin_id == $order['id']): ?>
                                    <tr id="checkin-<?php echo $order['id']; ?>">
                                        <td colspan="10" class="details-row">
                                            <div class="checkin-details">
                                                <div class="detail-group">
                                                    <h4>基本信息</h4>
                                                    <p><strong>手机号：</strong> <?php echo $order['guest_mobile']; ?></p>
                                                    <p><strong>证件号码：</strong> <?php echo $order['id_number'] ?: '-'; ?></p>
                                                    <p><strong>操作员：</strong> <?php echo $order['operator_name']; ?></p>
                                                </div>

                                                <div class="detail-group">
                                                    <h4>费用信息</h4>
                                                    <p><strong>房价：</strong> ￥<?php echo number_format($order['room_rate'], 2); ?> /天</p>
                                                    <p><strong>押金：</strong> ￥<?php echo number_format($order['deposit_amount'], 2); ?></p>
                                                    <p><strong>实际入住：</strong> <?php echo date('Y-m-d H:i', strtotime($order['checkin_time'])); ?></p>
                                                    <p><strong>预计退房：</strong> <?php echo $order['checkout_time'] ? date('Y-m-d H:i', strtotime($order['checkout_time'])) : '-'; ?></p>
                                                </div>

                                                <div class="detail-group">
                                                    <h4>其他信息</h4>
                                                    <p><strong>备注：</strong> <?php echo $order['remark'] ?: '-'; ?></p>
                                                    <p><strong>创建时间：</strong> <?php echo date('Y-m-d H:i', strtotime($order['create_time'])); ?></p>
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endif; ?>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>