<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance');

// 记录访问日志
record_log('访问财务管理首页');

// 获取今日收入
try {
    $stmt = $pdo->prepare("
        SELECT SUM(amount) AS total 
        FROM finance_payments 
        WHERE type = 1 AND DATE(payment_time) = CURDATE() AND status = 1
    ");
    $stmt->execute();
    $today_income = $stmt->fetch()['total'] ?: 0;
} catch (PDOException $e) {
    $error = '获取今日收入失败：' . $e->getMessage();
    $today_income = 0;
}

// 获取本月收入
try {
    $stmt = $pdo->prepare("
        SELECT SUM(amount) AS total 
        FROM finance_payments 
        WHERE type = 1 AND DATE_FORMAT(payment_time, '%Y%m') = DATE_FORMAT(CURDATE(), '%Y%m') AND status = 1
    ");
    $stmt->execute();
    $month_income = $stmt->fetch()['total'] ?: 0;
} catch (PDOException $e) {
    $error = '获取本月收入失败：' . $e->getMessage();
    $month_income = 0;
}

// 获取本年收入
try {
    $stmt = $pdo->prepare("
        SELECT SUM(amount) AS total 
        FROM finance_payments 
        WHERE type = 1 AND YEAR(payment_time) = YEAR(CURDATE()) AND status = 1
    ");
    $stmt->execute();
    $year_income = $stmt->fetch()['total'] ?: 0;
} catch (PDOException $e) {
    $error = '获取本年收入失败：' . $e->getMessage();
    $year_income = 0;
}

// 获取今日退款
try {
    $stmt = $pdo->prepare("
        SELECT SUM(amount) AS total 
        FROM finance_payments 
        WHERE type = 2 AND DATE(payment_time) = CURDATE() AND status = 2
    ");
    $stmt->execute();
    $today_refund = $stmt->fetch()['total'] ?: 0;
} catch (PDOException $e) {
    $error = '获取今日退款失败：' . $e->getMessage();
    $today_refund = 0;
}

// 获取未结算佣金总额
try {
    $stmt = $pdo->prepare("
        SELECT SUM(commission_amount) AS total 
        FROM finance_commissions 
        WHERE settlement_status = 1
    ");
    $stmt->execute();
    $unsettled_commission = $stmt->fetch()['total'] ?: 0;
} catch (PDOException $e) {
    $error = '获取未结算佣金失败：' . $e->getMessage();
    $unsettled_commission = 0;
}

// 获取最近5笔收支记录
try {
    $stmt = $pdo->prepare("
        SELECT p.*, 
               CASE 
                   WHEN p.booking_id IS NOT NULL THEN b.booking_no
                   WHEN p.checkin_id IS NOT NULL THEN c.checkin_no
                   ELSE NULL
               END AS order_no,
               CASE 
                   WHEN p.booking_id IS NOT NULL THEN b.guest_name
                   WHEN p.checkin_id IS NOT NULL THEN c.guest_name
                   ELSE NULL
               END AS guest_name
        FROM finance_payments p
        LEFT JOIN booking_orders b ON p.booking_id = b.id
        LEFT JOIN checkin_orders c ON p.checkin_id = c.id
        ORDER BY p.payment_time DESC
        LIMIT 5
    ");
    $stmt->execute();
    $recent_payments = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取最近收支记录失败：' . $e->getMessage();
    $recent_payments = [];
}

// 获取最近5笔佣金记录
try {
    $stmt = $pdo->prepare("
        SELECT c.*, o.channel_name, b.booking_no
        FROM finance_commissions c
        JOIN ota_channels o ON c.channel_id = o.id
        JOIN booking_orders b ON c.booking_id = b.id
        ORDER BY IFNULL(c.settlement_time, c.id) DESC
        LIMIT 5
    ");
    $stmt->execute();
    $recent_commissions = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取最近佣金记录失败：' . $e->getMessage();
    $recent_commissions = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>财务管理</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>财务管理</h2>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 财务数据概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>今日收入</h3>
                    <div class="number">￥<?php echo number_format($today_income, 2); ?></div>
                    <div class="desc">当日交易金额</div>
                </div>
                <div class="dashboard-card">
                    <h3>本月收入</h3>
                    <div class="number">￥<?php echo number_format($month_income, 2); ?></div>
                    <div class="desc">当月累计收入</div>
                </div>
                <div class="dashboard-card">
                    <h3>今日退款</h3>
                    <div class="number">￥<?php echo number_format($today_refund, 2); ?></div>
                    <div class="desc">当日退款金额</div>
                </div>
                <div class="dashboard-card">
                    <h3>未结算佣金</h3>
                    <div class="number">￥<?php echo number_format($unsettled_commission, 2); ?></div>
                    <div class="desc">待结算OTA佣金</div>
                </div>
            </div>

            <!-- 功能导航 -->
            <div class="function-links">
                <a href="payment.php" class="function-link">
                    <h3>账单管理</h3>
                </a>
                <a href="refund.php" class="function-link">
                    <h3>退款管理</h3>
                </a>
                <a href="commission.php" class="function-link">
                    <h3>佣金结算</h3>
                </a>
                <a href="../report/finance.php" class="function-link">
                    <h3>财务报表</h3>
                </a>
            </div>

            <!-- 最近交易记录 -->
            <h3>最近交易记录</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>支付单号</th>
                            <th>关联订单</th>
                            <th>客人</th>
                            <th>类型</th>
                            <th>金额(元)</th>
                            <th>支付方式</th>
                            <th>支付时间</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($recent_payments as $payment): ?>
                            <tr>
                                <td><?php echo $payment['payment_no']; ?></td>
                                <td><?php echo $payment['order_no'] ?: '-'; ?></td>
                                <td><?php echo $payment['guest_name'] ?: '-'; ?></td>
                                <td>
                                    <?php if ($payment['type'] == 1): ?>
                                        <span class="status-active">收款</span>
                                    <?php else: ?>
                                        <span class="status-inactive">退款</span>
                                    <?php endif; ?>
                                </td>
                                <td><?php echo number_format($payment['amount'], 2); ?></td>
                                <td>
                                    <?php
                                    $payment_methods = [
                                        1 => '现金',
                                        2 => '信用卡',
                                        3 => '微信',
                                        4 => '支付宝',
                                        5 => '银行转账'
                                    ];
                                    echo isset($payment_methods[$payment['payment_method']]) ? $payment_methods[$payment['payment_method']] : '未知';
                                    ?>
                                </td>
                                <td><?php echo date('Y-m-d H:i', strtotime($payment['payment_time'])); ?></td>
                                <td>
                                    <?php
                                    $status_text = '';
                                    $status_class = '';
                                    switch ($payment['status']) {
                                        case 1:
                                            $status_text = '已支付';
                                            $status_class = 'status-active';
                                            break;
                                        case 2:
                                            $status_text = '已退款';
                                            $status_class = 'status-warning';
                                            break;
                                        case 3:
                                            $status_text = '已取消';
                                            $status_class = 'status-inactive';
                                            break;
                                    }
                                    ?>
                                    <span class="<?php echo $status_class; ?>"><?php echo $status_text; ?></span>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (count($recent_payments) == 0): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无交易记录</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 最近佣金记录 -->
            <h3>最近佣金记录</h3>
            <div class="data-list">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>OTA渠道</th>
                            <th>预订单号</th>
                            <th>订单金额(元)</th>
                            <th>佣金比例</th>
                            <th>佣金金额(元)</th>
                            <th>结算状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($recent_commissions as $commission): ?>
                            <tr>
                                <td><?php echo $commission['id']; ?></td>
                                <td><?php echo $commission['channel_name']; ?></td>
                                <td><?php echo $commission['booking_no']; ?></td>
                                <td><?php echo number_format($commission['amount'], 2); ?></td>
                                <td><?php echo $commission['commission_rate']; ?>%</td>
                                <td><?php echo number_format($commission['commission_amount'], 2); ?></td>
                                <td>
                                    <?php if ($commission['settlement_status'] == 1): ?>
                                        <span class="status-warning">未结算</span>
                                    <?php else: ?>
                                        <span class="status-active">已结算</span>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (count($recent_commissions) == 0): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无佣金记录</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 财务统计数据 -->
            <h3>财务统计数据</h3>
            <div class="system-info">
                <table class="info-table">
                    <tr>
                        <td>本年总收入：</td>
                        <td>￥<?php echo number_format($year_income, 2); ?></td>
                    </tr>
                    <tr>
                        <td>OTA渠道收入：</td>
                        <td>
                            <?php
                            try {
                                $stmt = $pdo->prepare("
                                    SELECT SUM(p.amount) as total
                                    FROM finance_payments p
                                    JOIN booking_orders b ON p.booking_id = b.id
                                    JOIN ota_channels c ON b.channel_id = c.id
                                    WHERE p.type = 1 AND p.status = 1 AND YEAR(p.payment_time) = YEAR(CURDATE())
                                ");
                                $stmt->execute();
                                $ota_income = $stmt->fetch()['total'] ?: 0;
                                echo '￥' . number_format($ota_income, 2);
                            } catch (PDOException $e) {
                                echo '获取失败';
                            }
                            ?>
                        </td>
                    </tr>
                    <tr>
                        <td>OTA佣金总额：</td>
                        <td>
                            <?php
                            try {
                                $stmt = $pdo->prepare("
                                    SELECT SUM(commission_amount) as total
                                    FROM finance_commissions
                                    WHERE YEAR(IFNULL(settlement_time, NOW())) = YEAR(CURDATE())
                                ");
                                $stmt->execute();
                                $commission_total = $stmt->fetch()['total'] ?: 0;
                                echo '￥' . number_format($commission_total, 2);
                            } catch (PDOException $e) {
                                echo '获取失败';
                            }
                            ?>
                        </td>
                    </tr>
                    <tr>
                        <td>本年退款总额：</td>
                        <td>
                            <?php
                            try {
                                $stmt = $pdo->prepare("
                                    SELECT SUM(amount) as total
                                    FROM finance_payments
                                    WHERE type = 2 AND status = 2 AND YEAR(payment_time) = YEAR(CURDATE())
                                ");
                                $stmt->execute();
                                $refund_total = $stmt->fetch()['total'] ?: 0;
                                echo '￥' . number_format($refund_total, 2);
                            } catch (PDOException $e) {
                                echo '获取失败';
                            }
                            ?>
                        </td>
                    </tr>
                </table>
            </div>
        </div>
    </div>
</body>

</html>