<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('inventory_purchase');

// 记录访问日志
record_log('访问物资采购页面');

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加采购记录
    if ($_POST['action'] == 'add') {
        $item_id = isset($_POST['item_id']) ? intval($_POST['item_id']) : 0;
        $quantity = isset($_POST['quantity']) ? intval($_POST['quantity']) : 0;
        $supplier_id = isset($_POST['supplier_id']) ? intval($_POST['supplier_id']) : 0;
        $remarks = isset($_POST['remarks']) ? trim($_POST['remarks']) : '';

        if ($item_id <= 0 || $quantity <= 0 || $supplier_id <= 0) {
            $error = '请填写完整采购信息！';
        } else {
            try {
                // 获取物资信息，用于日志记录
                $stmt = $pdo->prepare("SELECT item_name FROM inv_items WHERE id = ?");
                $stmt->execute([$item_id]);
                $item = $stmt->fetch();

                // 获取供应商信息，用于日志记录
                $stmt = $pdo->prepare("SELECT supplier_name FROM inv_suppliers WHERE id = ?");
                $stmt->execute([$supplier_id]);
                $supplier = $stmt->fetch();

                if (!$item || !$supplier) {
                    $error = '物资或供应商不存在！';
                } else {
                    // 添加入库记录
                    $stmt = $pdo->prepare("
                        INSERT INTO inv_transactions (
                            item_id, transaction_type, quantity, supplier_id, 
                            operator_id, remarks
                        ) VALUES (?, 1, ?, ?, ?, ?)
                    ");
                    $result = $stmt->execute([
                        $item_id,
                        $quantity,
                        $supplier_id,
                        $_SESSION['user_id'],
                        $remarks
                    ]);

                    if ($result) {
                        // 更新库存
                        $stmt = $pdo->prepare("
                            UPDATE inv_stock SET quantity = quantity + ? WHERE item_id = ?
                        ");
                        $stmt->execute([$quantity, $item_id]);

                        record_log("采购入库：{$item['item_name']}，数量：{$quantity}，供应商：{$supplier['supplier_name']}");
                        $success = '采购入库成功！';
                    } else {
                        $error = '采购入库失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑采购记录
    elseif ($_POST['action'] == 'edit') {
        $transaction_id = isset($_POST['transaction_id']) ? intval($_POST['transaction_id']) : 0;
        $quantity = isset($_POST['quantity']) ? intval($_POST['quantity']) : 0;
        $supplier_id = isset($_POST['supplier_id']) ? intval($_POST['supplier_id']) : 0;
        $remarks = isset($_POST['remarks']) ? trim($_POST['remarks']) : '';

        if ($transaction_id <= 0 || $quantity <= 0 || $supplier_id <= 0) {
            $error = '请填写完整采购信息！';
        } else {
            try {
                // 获取原交易记录
                $stmt = $pdo->prepare("
                    SELECT t.item_id, t.quantity AS old_quantity, i.item_name, s.supplier_name 
                    FROM inv_transactions t
                    JOIN inv_items i ON t.item_id = i.id
                    JOIN inv_suppliers s ON t.supplier_id = s.id
                    WHERE t.id = ? AND t.transaction_type = 1
                ");
                $stmt->execute([$transaction_id]);
                $transaction = $stmt->fetch();

                if (!$transaction) {
                    $error = '采购记录不存在！';
                } else {
                    // 获取新供应商信息
                    $stmt = $pdo->prepare("SELECT supplier_name FROM inv_suppliers WHERE id = ?");
                    $stmt->execute([$supplier_id]);
                    $new_supplier = $stmt->fetch();

                    if (!$new_supplier) {
                        $error = '供应商不存在！';
                    } else {
                        // 计算库存变化量
                        $quantity_diff = $quantity - $transaction['old_quantity'];

                        // 更新交易记录
                        $stmt = $pdo->prepare("
                            UPDATE inv_transactions 
                            SET quantity = ?, supplier_id = ?, remarks = ?
                            WHERE id = ?
                        ");
                        $result = $stmt->execute([
                            $quantity,
                            $supplier_id,
                            $remarks,
                            $transaction_id
                        ]);

                        if ($result) {
                            // 更新库存
                            if ($quantity_diff != 0) {
                                $stmt = $pdo->prepare("
                                    UPDATE inv_stock 
                                    SET quantity = quantity + ? 
                                    WHERE item_id = ?
                                ");
                                $stmt->execute([$quantity_diff, $transaction['item_id']]);
                            }

                            record_log("编辑采购记录：{$transaction['item_name']}，数量：{$transaction['old_quantity']}=>{$quantity}，供应商：{$transaction['supplier_name']}=>{$new_supplier['supplier_name']}");
                            $success = '采购记录更新成功！';
                        } else {
                            $error = '采购记录更新失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除采购记录
    elseif ($_POST['action'] == 'delete') {
        $transaction_id = isset($_POST['transaction_id']) ? intval($_POST['transaction_id']) : 0;

        if ($transaction_id <= 0) {
            $error = '无效的交易记录ID！';
        } else {
            try {
                // 获取交易记录，用于库存更新和日志记录
                $stmt = $pdo->prepare("
                    SELECT t.*, i.item_name, s.supplier_name 
                    FROM inv_transactions t
                    JOIN inv_items i ON t.item_id = i.id
                    JOIN inv_suppliers s ON t.supplier_id = s.id
                    WHERE t.id = ? AND t.transaction_type = 1
                ");
                $stmt->execute([$transaction_id]);
                $transaction = $stmt->fetch();

                if (!$transaction) {
                    $error = '采购记录不存在！';
                } else {
                    // 开始事务
                    $pdo->beginTransaction();

                    // 更新库存（减去采购数量）
                    $stmt = $pdo->prepare("
                        UPDATE inv_stock 
                        SET quantity = quantity - ? 
                        WHERE item_id = ?
                    ");
                    $result1 = $stmt->execute([$transaction['quantity'], $transaction['item_id']]);

                    // 删除交易记录
                    $stmt = $pdo->prepare("DELETE FROM inv_transactions WHERE id = ?");
                    $result2 = $stmt->execute([$transaction_id]);

                    if ($result1 && $result2) {
                        $pdo->commit();
                        record_log("删除采购记录：{$transaction['item_name']}，数量：{$transaction['quantity']}，供应商：{$transaction['supplier_name']}");
                        $success = '采购记录删除成功！';
                    } else {
                        $pdo->rollBack();
                        $error = '采购记录删除失败！';
                    }
                }
            } catch (PDOException $e) {
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 判断是否显示添加表单
$show_add_form = isset($_GET['show_form']) && $_GET['show_form'] == 'add';

// 如果是编辑请求，获取采购详情
$edit_transaction = null;
if (isset($_GET['edit']) && intval($_GET['edit']) > 0) {
    $transaction_id = intval($_GET['edit']);
    try {
        $stmt = $pdo->prepare("
            SELECT t.*, i.item_name, s.supplier_name 
            FROM inv_transactions t
            JOIN inv_items i ON t.item_id = i.id
            JOIN inv_suppliers s ON t.supplier_id = s.id
            WHERE t.id = ? AND t.transaction_type = 1
        ");
        $stmt->execute([$transaction_id]);
        $edit_transaction = $stmt->fetch();
    } catch (PDOException $e) {
        $error = '获取采购详情失败：' . $e->getMessage();
    }
}

// 判断是否查看详情
$view_transaction_id = isset($_GET['view']) ? intval($_GET['view']) : 0;

// 获取所有物资
try {
    $stmt = $pdo->query("
        SELECT i.*, c.category_name, s.quantity AS stock_quantity
        FROM inv_items i
        JOIN inv_categories c ON i.category_id = c.id
        LEFT JOIN inv_stock s ON i.id = s.item_id
        WHERE i.status = 1
        ORDER BY i.id
    ");
    $items = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取物资列表失败：' . $e->getMessage();
    $items = [];
}

// 获取所有供应商
try {
    $stmt = $pdo->query("SELECT * FROM inv_suppliers WHERE status = 1 ORDER BY id");
    $suppliers = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取供应商列表失败：' . $e->getMessage();
    $suppliers = [];
}

// 获取所有采购记录
try {
    $stmt = $pdo->query("
        SELECT t.*, i.item_code, i.item_name, i.unit, c.category_name, 
               s.supplier_name, u.username AS operator_name
        FROM inv_transactions t
        JOIN inv_items i ON t.item_id = i.id
        JOIN inv_categories c ON i.category_id = c.id
        JOIN inv_suppliers s ON t.supplier_id = s.id
        LEFT JOIN sys_users u ON t.operator_id = u.id
        WHERE t.transaction_type = 1
        ORDER BY t.transaction_time DESC
    ");
    $transactions = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取采购记录失败：' . $e->getMessage();
    $transactions = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>物资采购</h2>
            <div class="breadcrumb">
                <a href="index.php">物资管理</a> &gt; 物资采购
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <?php if (!$show_add_form && !$edit_transaction): ?>
                    <a href="purchase.php?show_form=add" class="btn btn-primary">新增采购</a>
                <?php endif; ?>
            </div>

            <?php if ($show_add_form): ?>
                <!-- 添加采购表单 -->
                <h3>新增采购</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="item_id">采购物资：</label>
                            <select id="item_id" name="item_id" required>
                                <option value="">请选择物资</option>
                                <?php foreach ($items as $item): ?>
                                    <option value="<?php echo $item['id']; ?>">
                                        <?php echo $item['item_name']; ?> (<?php echo $item['item_code']; ?>) -
                                        当前库存: <?php echo $item['stock_quantity']; ?> <?php echo $item['unit']; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="quantity">采购数量：</label>
                            <input type="number" id="quantity" name="quantity" min="1" required>
                        </div>

                        <div class="form-group">
                            <label for="supplier_id">供应商：</label>
                            <select id="supplier_id" name="supplier_id" required>
                                <option value="">请选择供应商</option>
                                <?php foreach ($suppliers as $supplier): ?>
                                    <option value="<?php echo $supplier['id']; ?>"><?php echo $supplier['supplier_name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="remarks">备注：</label>
                            <textarea id="remarks" name="remarks" rows="3"></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="purchase.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($edit_transaction): ?>
                <!-- 编辑采购表单 -->
                <h3>编辑采购记录</h3>
                <div class="form-container">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="edit">
                        <input type="hidden" name="transaction_id" value="<?php echo $edit_transaction['id']; ?>">

                        <div class="form-group">
                            <label>采购物资：</label>
                            <span class="form-static"><?php echo $edit_transaction['item_name']; ?></span>
                        </div>

                        <div class="form-group">
                            <label for="quantity">采购数量：</label>
                            <input type="number" id="quantity" name="quantity" min="1" value="<?php echo $edit_transaction['quantity']; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="supplier_id">供应商：</label>
                            <select id="supplier_id" name="supplier_id" required>
                                <?php foreach ($suppliers as $supplier): ?>
                                    <option value="<?php echo $supplier['id']; ?>" <?php echo $edit_transaction['supplier_id'] == $supplier['id'] ? 'selected' : ''; ?>>
                                        <?php echo $supplier['supplier_name']; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="remarks">备注：</label>
                            <textarea id="remarks" name="remarks" rows="3"><?php echo $edit_transaction['remarks']; ?></textarea>
                        </div>

                        <div class="form-buttons">
                            <button type="submit" class="btn btn-primary">保存</button>
                            <a href="purchase.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <?php if (!$show_add_form && !$edit_transaction): ?>
                <h3>采购记录列表</h3>
                <!-- 采购记录列表 -->
                <div class="data-list">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>物资编码</th>
                                <th>物资名称</th>
                                <th>分类</th>
                                <th>数量</th>
                                <th>单位</th>
                                <th>供应商</th>
                                <th>采购时间</th>
                                <th>操作人</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($transactions as $transaction): ?>
                                <tr>
                                    <td><?php echo $transaction['id']; ?></td>
                                    <td><?php echo $transaction['item_code']; ?></td>
                                    <td><?php echo $transaction['item_name']; ?></td>
                                    <td><?php echo $transaction['category_name']; ?></td>
                                    <td><?php echo $transaction['quantity']; ?></td>
                                    <td><?php echo $transaction['unit']; ?></td>
                                    <td><?php echo $transaction['supplier_name']; ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($transaction['transaction_time'])); ?></td>
                                    <td><?php echo $transaction['operator_name']; ?></td>
                                    <td>
                                        <a href="purchase.php?view=<?php echo $transaction['id']; ?>" class="btn btn-sm btn-details">详情</a>
                                        <a href="purchase.php?edit=<?php echo $transaction['id']; ?>" class="btn btn-sm btn-edit">编辑</a>

                                        <form method="post" action="" style="display:inline;" onsubmit="return confirm('确定要删除此采购记录吗？此操作不可恢复且会影响库存量！');">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="transaction_id" value="<?php echo $transaction['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger">删除</button>
                                        </form>
                                    </td>
                                </tr>
                                <?php if ($view_transaction_id == $transaction['id']): ?>
                                    <tr id="transaction-<?php echo $transaction['id']; ?>">
                                        <td colspan="10" class="details-row">
                                            <div class="transaction-details">
                                                <div class="detail-group">
                                                    <h4>采购详情</h4>
                                                    <p><strong>采购时间：</strong> <?php echo date('Y-m-d H:i:s', strtotime($transaction['transaction_time'])); ?></p>
                                                    <p><strong>供应商：</strong> <?php echo $transaction['supplier_name']; ?></p>
                                                    <p><strong>操作人：</strong> <?php echo $transaction['operator_name']; ?></p>
                                                    <p><strong>备注：</strong> <?php echo $transaction['remarks'] ?: '-'; ?></p>
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endif; ?>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>