<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('stat_view');

// 记录访问日志
record_log('访问财务数据分析页面');

// 获取当前日期和时间范围
$today = date('Y-m-d');
$current_month = date('m');
$current_year = date('Y');
$yesterday = date('Y-m-d', strtotime('-1 day'));

// 获取筛选条件
$date_range = isset($_GET['date_range']) ? $_GET['date_range'] : 'month';
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-01'); // 默认本月初
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d'); // 默认今天
$payment_method = isset($_GET['payment_method']) ? intval($_GET['payment_method']) : 0;

// 根据日期范围设置默认值
if ($date_range == 'week') {
    $start_date = date('Y-m-d', strtotime('-6 days'));
    $end_date = $today;
} elseif ($date_range == 'month') {
    $start_date = date('Y-m-01');
    $end_date = date('Y-m-d', strtotime('last day of this month'));
} elseif ($date_range == 'year') {
    $start_date = date('Y-01-01');
    $end_date = date('Y-12-31');
} elseif ($date_range == 'last_month') {
    $start_date = date('Y-m-01', strtotime('first day of last month'));
    $end_date = date('Y-m-d', strtotime('last day of last month'));
} elseif ($date_range == 'last_year') {
    $start_date = date('Y-01-01', strtotime('-1 year'));
    $end_date = date('Y-12-31', strtotime('-1 year'));
}

// 计算日期跨度
$date_diff = strtotime($end_date) - strtotime($start_date);
$days_diff = round($date_diff / (60 * 60 * 24)) + 1;

// 财务数据统计
$finance_stats = [];
$daily_stats = [];
$monthly_stats = [];
$payment_type_stats = [];
$commission_stats = [];

// 总计金额
$total_income = 0;
$total_expense = 0;
$total_commission = 0;
$total_refund = 0;
$net_profit = 0;

try {
    // 获取收入（支付记录）
    $sql = "
        SELECT 
            SUM(CASE WHEN payment_method = 1 THEN amount ELSE 0 END) as cash_income,
            SUM(CASE WHEN payment_method = 2 THEN amount ELSE 0 END) as card_income,
            SUM(CASE WHEN payment_method = 3 THEN amount ELSE 0 END) as transfer_income,
            SUM(CASE WHEN payment_method = 4 THEN amount ELSE 0 END) as online_income,
            SUM(CASE WHEN payment_method = 5 THEN amount ELSE 0 END) as other_income,
            SUM(amount) as total_income
        FROM finance_payments
        WHERE (DATE(payment_time) BETWEEN ? AND ?)
        AND status = 1
        " . ($payment_method > 0 ? "AND payment_method = ?" : "");

    $params = [$start_date, $end_date];
    if ($payment_method > 0) {
        $params[] = $payment_method;
    }

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $income_data = $stmt->fetch();

    $total_income = $income_data['total_income'] ?: 0;

    // 获取退款总额
    $sql = "
        SELECT SUM(amount) as total_refund
        FROM finance_payments
        WHERE (DATE(payment_time) BETWEEN ? AND ?)
        AND type = 2 AND status = 1
        " . ($payment_method > 0 ? "AND payment_method = ?" : "");

    $params = [$start_date, $end_date];
    if ($payment_method > 0) {
        $params[] = $payment_method;
    }

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $refund_data = $stmt->fetch();

    $total_refund = $refund_data['total_refund'] ?: 0;

    // 获取佣金支出（已结算）
    $sql = "
        SELECT SUM(commission_amount) as total_commission
        FROM finance_commissions
        WHERE (DATE(settlement_time) BETWEEN ? AND ?)
        AND settlement_status = 1";

    $stmt = $pdo->prepare($sql);
    $stmt->execute([$start_date, $end_date]);
    $commission_data = $stmt->fetch();

    $total_commission = $commission_data['total_commission'] ?: 0;

    // 计算净利润
    $net_profit = $total_income - $total_refund - $total_commission;

    // 获取每日财务数据
    $sql = "
        SELECT 
            DATE(payment_time) as payment_date,
            SUM(CASE WHEN type = 1 THEN amount ELSE 0 END) as income,
            SUM(CASE WHEN type = 2 THEN amount ELSE 0 END) as refund,
            COUNT(DISTINCT id) as transaction_count
        FROM finance_payments
        WHERE (DATE(payment_time) BETWEEN ? AND ?)
        AND status = 1
        " . ($payment_method > 0 ? "AND payment_method = ?" : "") . "
        GROUP BY payment_date
        ORDER BY payment_date
    ";

    $params = [$start_date, $end_date];
    if ($payment_method > 0) {
        $params[] = $payment_method;
    }

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $payment_by_date = $stmt->fetchAll();

    // 获取每日佣金数据
    $sql = "
        SELECT 
            DATE(settlement_time) as settlement_date,
            SUM(commission_amount) as commission
        FROM finance_commissions
        WHERE (DATE(settlement_time) BETWEEN ? AND ?)
        AND settlement_status = 1
        GROUP BY settlement_date
        ORDER BY settlement_date
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute([$start_date, $end_date]);
    $commission_by_date = $stmt->fetchAll();

    // 将佣金数据转换为以日期为键的数组，便于合并
    $commission_by_date_map = [];
    foreach ($commission_by_date as $row) {
        $commission_by_date_map[$row['settlement_date']] = $row['commission'];
    }

    // 初始化每日统计数据
    $current_date = $start_date;
    while (strtotime($current_date) <= strtotime($end_date)) {
        $daily_stats[$current_date] = [
            'date' => $current_date,
            'income' => 0,
            'refund' => 0,
            'commission' => 0,
            'net_profit' => 0,
            'transaction_count' => 0
        ];
        $current_date = date('Y-m-d', strtotime($current_date . ' + 1 day'));
    }

    // 填充每日支付数据
    foreach ($payment_by_date as $payment) {
        if (isset($daily_stats[$payment['payment_date']])) {
            $daily_stats[$payment['payment_date']]['income'] = $payment['income'];
            $daily_stats[$payment['payment_date']]['refund'] = $payment['refund'];
            $daily_stats[$payment['payment_date']]['transaction_count'] = $payment['transaction_count'];
        }
    }

    // 填充每日佣金数据
    foreach ($commission_by_date_map as $date => $commission) {
        if (isset($daily_stats[$date])) {
            $daily_stats[$date]['commission'] = $commission;
        }
    }

    // 计算每日净利润
    foreach ($daily_stats as &$day) {
        $day['net_profit'] = $day['income'] - $day['refund'] - $day['commission'];
    }

    // 获取按月汇总的数据
    $monthly_data = [];
    foreach ($daily_stats as $date => $data) {
        $month = date('Y-m', strtotime($date));
        if (!isset($monthly_data[$month])) {
            $monthly_data[$month] = [
                'month' => $month,
                'income' => 0,
                'refund' => 0,
                'commission' => 0,
                'net_profit' => 0,
                'transaction_count' => 0
            ];
        }

        $monthly_data[$month]['income'] += $data['income'];
        $monthly_data[$month]['refund'] += $data['refund'];
        $monthly_data[$month]['commission'] += $data['commission'];
        $monthly_data[$month]['net_profit'] += $data['net_profit'];
        $monthly_data[$month]['transaction_count'] += $data['transaction_count'];
    }

    // 按月排序
    ksort($monthly_data);
    $monthly_stats = array_values($monthly_data);

    // 获取按支付方式统计
    $sql = "
        SELECT 
            payment_method,
            CASE 
                WHEN payment_method = 1 THEN '现金支付'
                WHEN payment_method = 2 THEN '刷卡支付'
                WHEN payment_method = 3 THEN '银行转账'
                WHEN payment_method = 4 THEN '在线支付'
                WHEN payment_method = 5 THEN '其他方式'
                ELSE '未知方式'
            END as payment_type_name,
            COUNT(id) as payment_count,
            SUM(CASE WHEN type = 1 THEN amount ELSE 0 END) as income,
            SUM(CASE WHEN type = 2 THEN amount ELSE 0 END) as refund,
            SUM(CASE WHEN type = 1 THEN amount ELSE -amount END) as net_amount
        FROM finance_payments
        WHERE (DATE(payment_time) BETWEEN ? AND ?)
        AND status = 1
        GROUP BY payment_method
        ORDER BY net_amount DESC
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute([$start_date, $end_date]);
    $payment_type_stats = $stmt->fetchAll();

    // 获取按渠道统计的佣金数据
    $sql = "
        SELECT 
            fc.channel_id,
            bc.channel_name,
            COUNT(fc.id) as commission_count,
            SUM(fc.commission_amount) as commission_amount,
            AVG(fc.commission_rate) as avg_commission_rate
        FROM finance_commissions fc
        JOIN booking_channels bc ON fc.channel_id = bc.id
        WHERE (DATE(fc.settlement_time) BETWEEN ? AND ?)
        AND fc.settlement_status = 1
        GROUP BY fc.channel_id, bc.channel_name
        ORDER BY commission_amount DESC
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute([$start_date, $end_date]);
    $commission_stats = $stmt->fetchAll();

    // 计算佣金占比
    foreach ($commission_stats as &$stat) {
        $stat['percentage'] = $total_commission > 0 ?
            round(($stat['commission_amount'] / $total_commission) * 100, 2) : 0;
    }
} catch (PDOException $e) {
    $error = '获取财务统计数据失败：' . $e->getMessage();
    $daily_stats = [];
    $monthly_stats = [];
    $payment_type_stats = [];
    $commission_stats = [];
}

// 获取支付方式列表
$payment_methods = [
    ['id' => 0, 'name' => '全部方式'],
    ['id' => 1, 'name' => '现金支付'],
    ['id' => 2, 'name' => '刷卡支付'],
    ['id' => 3, 'name' => '银行转账'],
    ['id' => 4, 'name' => '在线支付'],
    ['id' => 5, 'name' => '其他方式']
];
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>财务数据分析</title>
    <link rel="stylesheet" href="../style.css">
    <style>
        .summary-box {
            display: flex;
            flex-wrap: wrap;
            gap: 20px;
            margin-bottom: 20px;
        }

        .summary-item {
            flex: 1;
            min-width: 200px;
            background: #f8f9fa;
            padding: 15px;
            border-radius: 4px;
            border: 1px solid #ddd;
            text-align: center;
        }

        .summary-label {
            display: block;
            font-weight: bold;
            margin-bottom: 5px;
            color: #666;
        }

        .summary-value {
            display: block;
            font-size: 24px;
            font-weight: bold;
        }

        .income-value {
            color: #28a745;
        }

        .expense-value {
            color: #dc3545;
        }

        .profit-value {
            color: #007bff;
        }

        .chart-container {
            width: 100%;
            margin-bottom: 20px;
            overflow-x: auto;
        }

        .progress-bar {
            height: 20px;
            background-color: #e9ecef;
            border-radius: 3px;
            margin-top: 5px;
            overflow: hidden;
        }

        .progress-bar-fill {
            height: 100%;
            background-color: #4CAF50;
            text-align: center;
            line-height: 20px;
            color: white;
            transition: width 0.5s;
        }

        .expense-bar-fill {
            background-color: #dc3545;
        }

        .finance-card {
            border: 1px solid #ddd;
            border-radius: 4px;
            margin-bottom: 20px;
            background: #fff;
        }

        .finance-card-header {
            background: #f8f9fa;
            padding: 10px 15px;
            border-bottom: 1px solid #ddd;
            font-weight: bold;
        }

        .finance-card-body {
            padding: 15px;
        }

        .trend-table {
            width: 100%;
            border-collapse: collapse;
        }

        .trend-table th,
        .trend-table td {
            border: 1px solid #ddd;
            padding: 8px;
            text-align: center;
        }

        .trend-table th {
            background-color: #f2f2f2;
        }

        .positive-amount {
            color: #28a745;
        }

        .negative-amount {
            color: #dc3545;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>财务数据分析</h2>
            <div class="breadcrumb">
                <a href="index.php">统计分析</a> &gt; 财务数据分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="date_range">时间范围：</label>
                            <select id="date_range" name="date_range" onchange="updateDateRange()">
                                <option value="week" <?php echo $date_range == 'week' ? 'selected' : ''; ?>>近7天</option>
                                <option value="month" <?php echo $date_range == 'month' ? 'selected' : ''; ?>>本月</option>
                                <option value="last_month" <?php echo $date_range == 'last_month' ? 'selected' : ''; ?>>上月</option>
                                <option value="year" <?php echo $date_range == 'year' ? 'selected' : ''; ?>>本年</option>
                                <option value="last_year" <?php echo $date_range == 'last_year' ? 'selected' : ''; ?>>上年</option>
                                <option value="custom" <?php echo $date_range == 'custom' ? 'selected' : ''; ?>>自定义</option>
                            </select>
                        </div>
                        <div class="filter-item" id="custom_date" style="<?php echo $date_range == 'custom' ? '' : 'display:none;'; ?>">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                        </div>
                        <div class="filter-item" id="custom_date_end" style="<?php echo $date_range == 'custom' ? '' : 'display:none;'; ?>">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                        </div>
                    </div>
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="payment_method">支付方式：</label>
                            <select id="payment_method" name="payment_method">
                                <?php foreach ($payment_methods as $method): ?>
                                    <option value="<?php echo $method['id']; ?>" <?php echo $payment_method == $method['id'] ? 'selected' : ''; ?>><?php echo $method['name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">分析</button>
                            <a href="finance.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 财务概览 -->
            <div class="summary-box">
                <div class="summary-item">
                    <span class="summary-label">总收入(元)</span>
                    <span class="summary-value income-value">￥<?php echo number_format($total_income, 2); ?></span>
                    <span>日期范围：<?php echo $start_date; ?> 至 <?php echo $end_date; ?></span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">总退款(元)</span>
                    <span class="summary-value expense-value">￥<?php echo number_format($total_refund, 2); ?></span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">总佣金(元)</span>
                    <span class="summary-value expense-value">￥<?php echo number_format($total_commission, 2); ?></span>
                </div>
                <div class="summary-item">
                    <span class="summary-label">净利润(元)</span>
                    <span class="summary-value profit-value">￥<?php echo number_format($net_profit, 2); ?></span>
                    <span>利润率：<?php echo $total_income > 0 ? round(($net_profit / $total_income) * 100, 2) : 0; ?>%</span>
                </div>
            </div>

            <!-- 按支付方式分析 -->
            <div class="finance-card">
                <div class="finance-card-header">
                    收入来源分析（按支付方式）
                </div>
                <div class="finance-card-body">
                    <div class="data-list">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>支付方式</th>
                                    <th>交易笔数</th>
                                    <th>收入金额(元)</th>
                                    <th>收入占比</th>
                                    <th>退款金额(元)</th>
                                    <th>净收入(元)</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($payment_type_stats as $stat): ?>
                                    <tr>
                                        <td><?php echo $stat['payment_type_name']; ?></td>
                                        <td><?php echo $stat['payment_count']; ?></td>
                                        <td class="positive-amount"><?php echo number_format($stat['income'], 2); ?></td>
                                        <td>
                                            <?php
                                            $percentage = $total_income > 0 ? round(($stat['income'] / $total_income) * 100, 2) : 0;
                                            echo $percentage . '%';
                                            ?>
                                            <div class="progress-bar">
                                                <div class="progress-bar-fill" style="width: <?php echo $percentage; ?>%;">
                                                    <?php echo $percentage; ?>%
                                                </div>
                                            </div>
                                        </td>
                                        <td class="negative-amount"><?php echo number_format($stat['refund'], 2); ?></td>
                                        <td class="<?php echo $stat['net_amount'] >= 0 ? 'positive-amount' : 'negative-amount'; ?>"><?php echo number_format($stat['net_amount'], 2); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                                <?php if (count($payment_type_stats) == 0): ?>
                                    <tr>
                                        <td colspan="6" class="text-center">暂无支付方式数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>

            <!-- 佣金分析 -->
            <div class="finance-card">
                <div class="finance-card-header">
                    佣金支出分析（按渠道）
                </div>
                <div class="finance-card-body">
                    <div class="data-list">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>渠道名称</th>
                                    <th>结算笔数</th>
                                    <th>佣金金额(元)</th>
                                    <th>佣金占比</th>
                                    <th>平均佣金率</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($commission_stats as $stat): ?>
                                    <tr>
                                        <td><?php echo $stat['channel_name']; ?></td>
                                        <td><?php echo $stat['commission_count']; ?></td>
                                        <td class="negative-amount"><?php echo number_format($stat['commission_amount'], 2); ?></td>
                                        <td>
                                            <?php echo $stat['percentage']; ?>%
                                            <div class="progress-bar">
                                                <div class="progress-bar-fill expense-bar-fill" style="width: <?php echo $stat['percentage']; ?>%;">
                                                    <?php echo $stat['percentage']; ?>%
                                                </div>
                                            </div>
                                        </td>
                                        <td><?php echo number_format($stat['avg_commission_rate'], 2); ?>%</td>
                                    </tr>
                                <?php endforeach; ?>
                                <?php if (count($commission_stats) == 0): ?>
                                    <tr>
                                        <td colspan="5" class="text-center">暂无佣金数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>

            <!-- 月度趋势分析 -->
            <div class="finance-card">
                <div class="finance-card-header">
                    月度财务趋势
                </div>
                <div class="finance-card-body">
                    <div class="data-list">
                        <table class="trend-table">
                            <thead>
                                <tr>
                                    <th>月份</th>
                                    <th>交易笔数</th>
                                    <th>收入(元)</th>
                                    <th>退款(元)</th>
                                    <th>佣金(元)</th>
                                    <th>净利润(元)</th>
                                    <th>利润率</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($monthly_stats as $stat): ?>
                                    <tr>
                                        <td><?php echo $stat['month']; ?></td>
                                        <td><?php echo $stat['transaction_count']; ?></td>
                                        <td class="positive-amount"><?php echo number_format($stat['income'], 2); ?></td>
                                        <td class="negative-amount"><?php echo number_format($stat['refund'], 2); ?></td>
                                        <td class="negative-amount"><?php echo number_format($stat['commission'], 2); ?></td>
                                        <td class="<?php echo $stat['net_profit'] >= 0 ? 'positive-amount' : 'negative-amount'; ?>"><?php echo number_format($stat['net_profit'], 2); ?></td>
                                        <td>
                                            <?php
                                            $profit_rate = $stat['income'] > 0 ? round(($stat['net_profit'] / $stat['income']) * 100, 2) : 0;
                                            echo $profit_rate . '%';
                                            ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                                <?php if (count($monthly_stats) == 0): ?>
                                    <tr>
                                        <td colspan="7" class="text-center">暂无月度数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>

            <!-- 每日财务趋势 -->
            <div class="finance-card">
                <div class="finance-card-header">
                    每日财务明细
                </div>
                <div class="finance-card-body">
                    <div class="data-list">
                        <table class="trend-table">
                            <thead>
                                <tr>
                                    <th>日期</th>
                                    <th>交易笔数</th>
                                    <th>收入(元)</th>
                                    <th>退款(元)</th>
                                    <th>佣金(元)</th>
                                    <th>净利润(元)</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($daily_stats as $day): ?>
                                    <tr>
                                        <td><?php echo $day['date']; ?></td>
                                        <td><?php echo $day['transaction_count']; ?></td>
                                        <td class="positive-amount"><?php echo number_format($day['income'], 2); ?></td>
                                        <td class="negative-amount"><?php echo number_format($day['refund'], 2); ?></td>
                                        <td class="negative-amount"><?php echo number_format($day['commission'], 2); ?></td>
                                        <td class="<?php echo $day['net_profit'] >= 0 ? 'positive-amount' : 'negative-amount'; ?>"><?php echo number_format($day['net_profit'], 2); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                                <?php if (count($daily_stats) == 0): ?>
                                    <tr>
                                        <td colspan="6" class="text-center">暂无每日财务数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script>
        function updateDateRange() {
            var dateRange = document.getElementById('date_range').value;
            var customDateDiv = document.getElementById('custom_date');
            var customDateEndDiv = document.getElementById('custom_date_end');

            if (dateRange === 'custom') {
                customDateDiv.style.display = '';
                customDateEndDiv.style.display = '';
            } else {
                customDateDiv.style.display = 'none';
                customDateEndDiv.style.display = 'none';
            }
        }
    </script>
</body>

</html>